==> igniteui-react-charts-16.6.8.tgz: package/ES5/igr-stacked-bar-series.js <==
import * as tslib_1 from "tslib";
import { IgrVerticalStackedSeriesBase } from "./igr-vertical-stacked-series-base";
import { StackedBarSeries } from "./StackedBarSeries";
import { toPoint } from "igniteui-react-core/ES5/componentUtil";
/**
 * Represents a IgxDataChartComponent stacked bar series.
*/
var IgrStackedBarSeries = /** @class */ (function (_super) {
    tslib_1.__extends(IgrStackedBarSeries, _super);
    function IgrStackedBarSeries(props) {
        return _super.call(this, props) || this;
    }
    IgrStackedBarSeries.prototype.createImplementation = function () {
        return new StackedBarSeries();
    };
    Object.defineProperty(IgrStackedBarSeries.prototype, "i", {
        get: function () {
            return this._implementation;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrStackedBarSeries.prototype, "radiusX", {
        /**
         * Gets or sets the x-radius of the ellipse that is used to round the corners of the bar.
        */
        get: function () {
            return this.i.pw;
        },
        set: function (v) {
            this.i.pw = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrStackedBarSeries.prototype, "radiusY", {
        /**
         * Gets or sets the y-radius of the ellipse that is used to round the corners of the bar.
        */
        get: function () {
            return this.i.px;
        },
        set: function (v) {
            this.i.px = +v;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * Scrolls the series to display the item for the specified data item.
     * The series is scrolled by the minimum amount required to place the specified data item within
     * the central 80% of the visible axis.
    
    * @param item  * The data item (item) to scroll to.
    */
    IgrStackedBarSeries.prototype.scrollIntoView = function (item) {
        var iv = this.i.c8(item);
        return (iv);
    };
    /**
     * Gets the index of the item that resides at the provided world coordinates.
    
    * @param world  * The world coordinates of the requested item.
    */
    IgrStackedBarSeries.prototype.getItemIndex = function (world) {
        var iv = this.i.e5(toPoint(world));
        return (iv);
    };
    /**
     * Gets the item that is the best match for the specified world coordinates.
    
    * @param world  * The world coordinates to use.
    */
    IgrStackedBarSeries.prototype.getItem = function (world) {
        var iv = this.i.fm(toPoint(world));
        return (iv);
    };
    /**
     * For a category plotted series, returns the current width of the items within the categories. This only returns a value if the items have some form of width (e.g. columns, bars, etc.) otherwise 0 is returned.
    
    */
    IgrStackedBarSeries.prototype.getItemSpan = function () {
        var iv = this.i.ed();
        return (iv);
    };
    return IgrStackedBarSeries;
}(IgrVerticalStackedSeriesBase));
export { IgrStackedBarSeries };

==> igniteui-react-charts-16.11.1.tgz: package/ES5/igr-stacked-bar-series.js <==
import * as tslib_1 from "tslib";
import { IgrVerticalStackedSeriesBase } from "./igr-vertical-stacked-series-base";
import { StackedBarSeries } from "./StackedBarSeries";
import { toPoint } from "igniteui-react-core/ES5/componentUtil";
/**
 * Represents a IgxDataChartComponent stacked bar series.
*/
var IgrStackedBarSeries = /** @class */ (function (_super) {
    tslib_1.__extends(IgrStackedBarSeries, _super);
    function IgrStackedBarSeries(props) {
        return _super.call(this, props) || this;
    }
    IgrStackedBarSeries.prototype.createImplementation = function () {
        return new StackedBarSeries();
    };
    Object.defineProperty(IgrStackedBarSeries.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrStackedBarSeries.prototype, "radiusX", {
        /**
         * Gets or sets the x-radius of the ellipse that is used to round the corners of the bar.
        */
        get: function () {
            return this.i.p3;
        },
        set: function (v) {
            this.i.p3 = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrStackedBarSeries.prototype, "radiusY", {
        /**
         * Gets or sets the y-radius of the ellipse that is used to round the corners of the bar.
        */
        get: function () {
            return this.i.p4;
        },
        set: function (v) {
            this.i.p4 = +v;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * Scrolls the series to display the item for the specified data item.
     * The series is scrolled by the minimum amount required to place the specified data item within
     * the central 80% of the visible axis.
    
    * @param item  * The data item (item) to scroll to.
    */
    IgrStackedBarSeries.prototype.scrollIntoView = function (item) {
        var iv = this.i.c9(item);
        return (iv);
    };
    /**
     * Gets the index of the item that resides at the provided world coordinates.
    
    * @param world  * The world coordinates of the requested item.
    */
    IgrStackedBarSeries.prototype.getItemIndex = function (world) {
        var iv = this.i.e8(toPoint(world));
        return (iv);
    };
    /**
     * Gets the item that is the best match for the specified world coordinates.
    
    * @param world  * The world coordinates to use.
    */
    IgrStackedBarSeries.prototype.getItem = function (world) {
        var iv = this.i.fp(toPoint(world));
        return (iv);
    };
    /**
     * For a category plotted series, returns the current width of the items within the categories. This only returns a value if the items have some form of width (e.g. columns, bars, etc.) otherwise 0 is returned.
    
    */
    IgrStackedBarSeries.prototype.getItemSpan = function () {
        var iv = this.i.eg();
        return (iv);
    };
    return IgrStackedBarSeries;
}(IgrVerticalStackedSeriesBase));
export { IgrStackedBarSeries };
